import React, { useEffect, useState } from "react";
import AgentActivityBar from "./AgentActivityBar";

function AgentActivityBars({client}) {
    const [ agents, setAgents ] = useState([])
    const [ errorMsg, setErrorMsg ] = useState('')
    
    const today = new Date(Date.now())
    const year = today.getFullYear()
    const month = today.getMonth()
    const day = today.getDate()

    function agentHasActivity(agent) {
        // If the agent has activity, determine if some of that activity is for the previous day or the current day. Agent is not displayed if the activity is only for the previous day.
        if (agent.history.hasOwnProperty(year) && agent.history[year].hasOwnProperty(month) && agent.history[year][month].hasOwnProperty(day) && agent.history[year][month][day].hasOwnProperty('activity')) {
            const yesterdaysActivity = []
            const todaysActivity = []
            
            agent.history[year][month][day]['activity'].forEach(activity => {
                const activityDate = new Date(activity.timestamp)
                const activityDay = activityDate.getDate()

                if(activityDay === day) todaysActivity.push(activity)
                else yesterdaysActivity.push(activity)
            })

            if ( (yesterdaysActivity.length === 0 || yesterdaysActivity.length > 0) &&          
                 todaysActivity.length > 0 ) return true
            else return false
        }

        return false
    }

    const agentActivityBars = agents.map(agent => {
        return ( 
            <tr>
                <td>{`${agent.firstName} ${agent.lastName}`}</td>
                <td colSpan="24">
                    <AgentActivityBar agent={agent} setErrorMsg={setErrorMsg}/>
                </td>
            </tr> 
        )
    })

    useEffect(async () => {
        console.log('running use effect')
        const data = JSON.stringify({
            "collection": "agents",
            "database": "test",
            "dataSource": "Cluster0",
        });
        
        try {
           const response = await client.request.invokeTemplate("getAgents", { body: data })

           if (response.status === 200) {
               const newAgents = JSON.parse(response.response).documents
               const agentsWithActivity = newAgents.filter(agent => agentHasActivity(agent));
               
               console.log(agentsWithActivity)
               setAgents([ ...agentsWithActivity ])
           }
        } catch (e) {
            console.error(e)
        }
    },[])

    return agentActivityBars || errorMsg
}

export default AgentActivityBars